# This is a Posix SH include file that should be sourced at the top of
# every job.  It initializes the environment for various clusters so
# that the rest of the HWRF or Rocoto can run properly.

# Workaround for misconfigured or problematic clusters.  The TMPDIR
# variable sets the directory for temporary files.  Sometimes this is
# set to a location that does not exist or is in memory.  The $TMPDIR
# variable is not always passed through to batch jobs.  This
# workaround sets it to some other specified location from the
# $HWRF_FORCE_ALT_TMPDIR or $HWRF_FORCE_TMPDIR variables.  We use
# $HWRF_FORCE_TMPDIR as the default for all jobs, and allow per-job
# overrides via $HWRF_FORCE_ALT_TMPDIR.  Such overrides are needed
# only for jobs that are scrubbing the parent of the regular tmpdir,
# or that run after that directory is removed.

if [[ "Q${HWRF_FORCE_ALT_TMPDIR:-}" != "Q" ]] ; then
    if [[ ! -d "$HWRF_FORCE_ALT_TMPDIR" ]] ; then
        if ( mkdir -p "$HWRF_FORCE_ALT_TMPDIR" ) ; then
            :  # trick to avoid triggering a set -e during a race condition
        fi
    fi
    export TMPDIR="$HWRF_FORCE_ALT_TMPDIR"
elif [[ "Q${HWRF_FORCE_TMPDIR:-}" != "Q" ]] ; then
    if [[ ! -d "$HWRF_FORCE_TMPDIR" ]] ; then
        if ( mkdir -p "$HWRF_FORCE_TMPDIR" ) ; then
            :  # trick to avoid triggering a set -e during a race condition
        fi
    fi
    export TMPDIR="$HWRF_FORCE_TMPDIR"
fi

if [[ "QQ$WHERE_AM_I" == QQ ]] ; then
   if [[ -d /lfs3 ]] ; then
       export WHERE_AM_I=jet
   elif [[ -d /scratch3 ]] ; then
       if ( grep E5-2690 /proc/cpuinfo > /dev/null 2>&1 ) ; then
           export WHERE_AM_I=theia
       else
           export WHERE_AM_I=zeus
       fi
   elif [[ -d /gpfs/hps && -e /etc/SuSE-release ]] ; then
       export WHERE_AM_I=wcosscray
   elif [[ -d /dcom && -d /hwrf ]] ; then
       export WHERE_AM_I=wcoss
   elif [[ -d /glade ]] ; then
       export WHERE_AM_I=yellowstone
   elif [[ -d /data && -d /home && -d /scratch ]] ; then
       export WHERE_AM_I=s4
   fi
fi

moduleuse=$HOMEhwrf/modulefiles/$WHERE_AM_I
case "${WHERE_AM_I:-unknown}" in
    jet)          . /apps/lmod/lmod/init/sh ;;
    zeus)         . /usr/share/Modules/init/sh ;;
    ttfri)        . /opt/modules/Modules/3.2.9/init/sh ;;
    s4)           : ;;
    yellowstone)
#        . /usr/share/Modules/init/sh
        export PATH=/glade/p/work/strahan/rocoto/hwrf-rocoto/bin:$PATH
        moduleuse=no
        ;;
    wcoss|wcoss2|wcoss1)
        moduleuse=$HOMEhwrf/modulefiles/wcoss
        . /usrx/local/Modules/default/init/sh 
        module purge
        ;;
    wcosscray)
        if [[ -e /gpfs/td2 ]] ; then
	    moduleuse=$HOMEhwrf/modulefiles/wcossluna
	else
	    moduleuse=$HOMEhwrf/modulefiles/wcosssurge
	fi
	if ( ! which modulecmd ) ; then
	    . /opt/modules/default/init/sh
	fi
        set +e # modules are totally broken on WCOSS Cray so several
               # below commands may fail depending on what the user
               # does, but everything should be okay by the end of
               # this block
	# Need to use these before module purge will work:
	module use /opt/cray/ari/modulefiles/
        module use /opt/cray/craype/default/alt-modulefiles
        module use /opt/cray/alt-modulefiles
        module use /opt/modulefiles
        module use /usrx/local/prod/modulefiles
        module use /gpfs/hps/nco/ops/nwprod/lib/modulefiles/
        module purge
        module purge
	module use /opt/cray/ari/modulefiles/
        module use /opt/cray/craype/default/alt-modulefiles
        module use /opt/cray/alt-modulefiles
        module use /opt/modulefiles
        module use /usrx/local/prod/modulefiles
        module use /gpfs/hps/nco/ops/nwprod/lib/modulefiles/
	;;
    theia)        : ;;
    *)
        echo "WARNING: UNSUPPORTED SYSTEM $WHERE_AM_I" 1>&2
esac

if [[ "$moduleuse" != no ]] ; then
    module use $moduleuse 
    
    if [[ "${GSI_DOMAIN:-}QQ" == QQ ]] ; then
        echo NOT A GSI JOB - LOADING HWRF/run
        module load HWRF/run
    else
        echo GSI JOB - LOAD HWRF/rungsi
        module load HWRF/rungsi
    fi
fi

if [[ "${QUIET_PRE_JOB:-NO}" != YES ]] ; then
    if [[ "$WHERE_AM_I" == zeus || "$WHERE_AM_I" == jet || "$WHERE_AM_I" == ttfri ]] ; then 
        echo ====================PBS_NODEFILE CONTENTS===================
        ( set +eu ; cat "$PBS_NODEFILE" ; /bin/true )
    fi
    echo =======================/proc/meminfo========================
    cat /proc/meminfo
    echo ========================ps auxwww===========================
    ps auxwww
    echo ===========================env==============================
    env
    echo ======================df -h /dev/shm========================
    df -h /dev/shm
    echo ========================ulimit -a===========================
    ulimit -a
    echo ============================================================
fi

set +u
if [[ "Q${utilexec:-}" != Q ]] ; then
    export PATH=$utilexec:$PATH
fi
if [[ "Q${EXEChwrf:-}" != Q ]] ; then
    export PATH=$EXEChwrf:$PATH
elif [[ "Q${HOMEhwrf:-}" != Q ]] ; then
    export PATH=$HOMEhwrf/exec:$PATH
fi
set -u
