#!/bin/ksh
#
# hwrf_rtofs_init.sh prepares the ocean files for the hurricane model
# the 3 main functions is does is create
#   - boundary conditions - these may be from the rtofs full domain run, or
#                           a mixture of the rtofs and the previous cycle
#                           of the hurricane run.
#   - initial conditions - restart file from archive file
#   - forcing files - from template
#
# /mnt/lfs3/projects/hwrf-data/hwrf-input/GDAS1/2015/2015072900

set -x

echo "*** Started script $0"

. $COMhwrf/$stormlabel.holdvars.txt
. ./hycom_settings

SKIPAROUND=NO
if [ $SKIPAROUND == YES ]; then
ln -sf ../pre-hycominit/* .
exit
fi

#############################################################

#jet testing
# export RTOFSDIR=/mnt/pan2/projects/hwrfv3/Dan.Iredell/noscrub/rtofs
# export GETGES_COM=/mnt/pan2/projects/hwrfv3/Dan.Iredell/noscrub

if [[ ${CASE_ROOT} == "FORECAST" ]];
then 
# 	export RTOFSDIR=/com/rtofs/prod
#	export GETGES_COM=/com
 	export RTOFSDIR=/gpfs/gd1/emc/marine/noscrub/Dan.Iredell/hwrfdata/rtofs
	export GETGES_COM=/marine/noscrub/input/hwrfdata
else
#wcoss testing
 	export RTOFSDIR=/gpfs/gd1/emc/marine/save/Dan.Iredell/hwrfdata/rtofs
	export GETGES_COM=/marine/noscrub/Dan.Iredell/hwrfdata
fi

export utilscript=$utilexec/../ush
export pdy=$YMDH
export cyc=$CYCLE
export NDATE=$utilexec/ndate
export NHOUR=$utilexec/nhour
#export GRBINDEX=$utilexec/grbindex 
#export WGRIB=$utilexec/wgrib
#export CNVGRIB=$utilexec/cnvgrib
#export GRB2INDEX=$utilexec/grb2index 
#export WGRIB2=$utilexec/wgrib2


export prevcycle=`${utilexec}/ndate -6 $YMDH`
cycm1=`echo $prevcycle | cut -c9-10`

# find forecast_hours
# --hsk
export spinlength=${spinlength:-24}
forecast_length=${forecast_length:-126}
let fsecs=$forecast_length*3600
secs=${C_NSECS:-$fsecs}
let forecast_hours=$secs/3600

enddate=`${utilexec}/ndate $forecast_hours $YMDH`
ocean_status=0
oceanstatusfile=${COMOUT}/${out_prefix}.hycom_settings

# determine what needs to be done for this run
# ex. 2005082912/12l/KATRINA.2005082912/OCEAN

#----             Check Ocean is Staged or not --------------------
#------------------------------------------------------------------
# DAN - skipping this for now
OCEAN_staged=${OCEAN_staged:-NO}
if [ "$OCEAN_staged" == YES ]
then
  OCEAN_full=$STAGE_DIR/$STORMID/$YEAR$MONTH$DATE$CYCLE/OCEAN
  if [[ -d $OCEAN_full &&
        -d $OCEAN_full/forcing &&
        -d $OCEAN_full/nest &&
        -d $OCEAN_full/restarts ]]
  then
     echo "set to staged but nothing is staged"
     exit 0
  fi
fi

###############################################################
# OCEAN_staged = NO:
#     Create BC, IC and Forcings
#--------------------------------------------------------------
ocean_status=0
boundary_conditions_from_rtofs=T
same_domain=1  ## ??
     
force_coldstart=${force_coldstart:-0}
if [[ $same_domain = 1 && $force_coldstart = 0 ]]
then
   spin=T
   create_subdomain=F
else
   spin=F
   create_subdomain=T
fi
  
echo $PDY: Setting-up BC, IC and Forcings

#################################################################################
# 1. BOUNDARY CONDITIONS

# 1.1a create subdomain from rtofs

boundary_conditions_from_rtofs=${boundary_conditions_from_rtofs:-T}
if [[ $create_subdomain = T || $boundary_conditions_from_rtofs = T ]]
then

# determine set of archives that subset_bdry needs to create the BC files. 
  $USHhwrf/hycom/hwrf_rtofs_subset_bdry_init.sh $spinlength $forecast_length
else
  echo "use to get subdomain from previous cycle and then needed 6 more"
fi

echo  SKIPPING THIS PART, BELOW is for bc not from rtofs

#################################################################################
# 2. INITIAL CONDITIONS

###########
# if $SPINUP_DATA/*restart*n00 is same as YEARMONTHDATECYCLE
#   then run restart2restart (subregioning) to this domain for the IC
#   else
#     if $SPINUP_DATA/*restart*n00 is same as YEARMONTHDATECYCLE-6
#     then run restart2restart (subregioning) to this domain and use for spin
#     else run archv2restart on archive from $SPINUP_DATA from YEARMONTHDATECYCLE-6 and use for spin
#
# new logic:
# run restart2restart on $SPINUP_DATA/*restart*n00
# if this restart file is not same time as YEARMONTHDATECYCLE-6
#   then run archv2restart on archive from $SPINUP_DATA for YEARMONTHDATECYCLE-6 
# use created restart to spin for 6 hours
###########

#
echo SPINNING an analysis
$USHhwrf/hycom/hwrf_rtofs_spin.sh
spinrc=$?

ocean_status=0

# if spin fails, then get restart file from rtofs
#dan: what if spin fails???!!! here we get 6hour restart from coupled forecast (not available in global)
if [ $spinrc != 0 ]
then
    # postmsg
    echo spin failed, what to do now?
#    cp -p $HISTDATA/hwrf_$RUNmodIDout.t${cycm1}z.nest_restartR.a $CSTREAM/OCEAN/restarts/restart_pre.a
#    cp -p $HISTDATA/hwrf_$RUNmodIDout.t${cycm1}z.nest_restartR.b $CSTREAM/OCEAN/restarts/restart_pre.b
else
   let ocean_status=ocean_status+1
# copy restarts to comout for next cycle spin
#   cp $CSTREAM/OCEAN/restarts/restart_out.a $COMOUT/hwrf_${RUNmodIDout}.t${cyc}z.spin_restart.a
#   cp $CSTREAM/OCEAN/restarts/restart_out.b $COMOUT/hwrf_${RUNmodIDout}.t${cyc}z.spin_restart.b
fi

###################################################################
# Diagnostics
#------------
if [ $ocean_status -ne 0 ]
then
   echo '--- HWRF_RTOFS_INIT.SH --- '
   echo ' IC, BC, and FORCING are ready and '
   echo ' Set flag for a coupled model run'
else
   echo '--- HWRF_RTOFS_INIT.SH --- '
   echo ' A coupled model run is NOT ready '
fi
echo "*** Finished script $0"

