#!/bin/ksh
#########################################################################
# Usage: ofs_seasforce3.sh                                         #
#                                                                       #
# Description: This script copies the GFS/GDAS flux files and           #
#              interpolate them to generates the seashore forcing files #
#              for the Ocean Forecast Model                             #
#                                                                       #
# History:                                                              #
#    06-16-2005  Dan Iredell                                            #
#    06-01-2006  Ilya Rivin: add sea level pressure forcing             #
#    09-30-2009  Dan Iredell - version for hwrf                         #
#    03-24-2010  Dan Iredell - overhaul for pressure from master        #
#########################################################################

set -x

echo "*** Started script $0"
# USE THIS NOW
# module use /pan2/projects/hwrf-vd/soft/modulefiles/
# module load grib_util/v1.0.1

skipovergribstuff=0
if [ $skipovergribstuff -eq 1 ]
then

cp /mnt/pan2/projects/hwrfv3/Dan.Iredell/noscrub/gfs/prod/2015061600/* .
#cp /mnt/pan2/projects/hwrfv3/Dan.Iredell/pytmp/HyHWRF-2015/2015061600/02L/fromgyre/2015061600/* .

else

if test $# -ne 2
then
  echo Usage: $0 startdate enddate
  exit
fi
export NDATE=$utilexec/ndate
export NHOUR=$utilexec/nhour

# hsk's doing @10/24/2011
InstanV='Y' # [Y/N] for using TR to extract instantaneous values
# hsk's doing:

date1=$1
date2=$2
sea_lev_pres=PRMSL

echo " GETGES_COM=${GETGES_COM}"

ihours=0
if [ $mode = 'anal' ]
then
  ihours=1
  global=gdas
fi
if [ $mode = 'fcst' ]
then
  ihours=3
  global=gfs
fi

# only get grib1

nm=`$utilexec/nhour $date2 $date1`
let nm=nm/ihours+3
echo $nm > listflx.dat
rdate1=`$utilexec/ndate -$ihours $date1`
rdate2=`$utilexec/ndate $ihours $date2`
datei=$rdate1

intvl=3
pfile=pgbges
sfile=sfcflx    # grib1
sfile=sfcflx2   # grib2

while [[ $datei -le $rdate2 ]]
do
  # pressure file
  pf1=`$USHofs/ofs_getges.sh -e $envir -n $global -t $pfile -v $datei`
  pgfile=`basename $pf1`
  pgfile=$datei.$pgfile
#  ln -s $pf1 $pgfile

  # surface flux file
  sf=`$USHofs/ofs_getges.sh -e $envir -n $global -t $sfile -v $datei`
  flxfile=`basename $sf`
  flxfile=$datei.$flxfile

# hsk's doing: select instantaneous variables that are come with both (avg,inst).
# 10/24/2011
if [ $InstanV = Y ]; then
		# cp $sf gfs.$flxfile
  ln -s $sf  gfs.$flxfile
  ln -s $pf1 gfs.$pgfile

		# if [ $mode = 'anal' ]; then
  $USHofs/ofs_forcing_extract.sh gfs.$flxfile $flxfile gfs.$pgfile $pgfile
		# fi
else
		# cp $sf $flxfile
  ln -s $sf $flxfile
fi
# end hsk's doing:

  mv $flxfile g2.$flxfile
  $CNVGRIB -g21 g2.$flxfile $flxfile

  ${utilexec}/grbindex $pgfile $pgfile.idx
  ${utilexec}/grbindex $flxfile $flxfile.idx
  export GRBFILE=$flxfile
  export IDXFILE=$flxfile.idx
  rm -f kpds.dat
  $EXECofs/ofs_getkpds
  atmgds='255 '`cat kpds.dat`

  cp $flxfile $flxfile.before.copygb
  $COPYGB -g"$atmgds" -x -a -i0 $pgfile $flxfile

  rm -f $flxfile.idx
  ${utilexec}/grbindex $flxfile $flxfile.idx

  echo $datei $flxfile $pgfile $sf $pf1 >>listflx.dat
  datei=`$utilexec/ndate $ihours $datei`

done
fi  # skip over grib stuff

#################################################################
# Interpolate to OFS grid
#################################################################
#- UNIT  7  - FILE intp_pars.dat, COTROL RUN PARAMETRS
#- UNIT  8  - FILE regional.grid.b, DESCRIPTOR FOR HYCOM GRID
#-            (READ IN mod_geom.f90)
#- UNIT  9  - FILE regional.grid.a, HYCOM GRID
#-            (READ IN mod_geom.f90)
#- UNIT 33  - FILE listflx.dat, LIST OF DATES AND MRF FLUS FILES TO
#-            BE USED IN INTERPOLATION.
#- UNIT 59  - FILE regional.depth.a, HYCOM BATHIMETRY
#-            (READ IN mod_geom.f90)
#- UNIT 61  - FILE regional.mask.a, HYCOM mask
#-            (READ IN mod_geom.f90)
#- UNIT 81  - MRF GRIBBED FLUXES FILES WITH THE NAMES FROM THE LIST
#-            SPECIFIED IN listflx.dat.
#- UNIT 82  - THE SAME
#################################################################

cat > intp_pars.dat << EOF
&intp_pars
avstep = 1.,      ! averaging fluxes (in hours)
mrffreq = 1.,     ! frequency of MRF fluxes (in hours)  = mrffreq for no averaging
flxflg = 5,       ! Type of HYCOM input (=4 => nhycom=7 and =5 => nhycom=8)
dbgn = 1,         ! debugging =0 - no dbg; =1,2,3 - add output
avg3 = 2,         ! if avg3 = 1, then averaged fluxes are converted to instantaneous fields
wslocal = 1       ! if  wslocal = 1, then wind stress are computed from wind velcoities
/
EOF

msg=" `date`  -- $pgm for $adate started "

export XLFRTEOPTS="unit_vars=yes:buffering=disable_all"
export XLFUNIT_7=intp_pars.dat
export XLFUNIT_8=regional.grid.b
export XLFUNIT_9=regional.grid.a
export XLFUNIT_33=listflx.dat
export XLFUNIT_59=regional.depth.a
export XLFUNIT_61=regional.mask.a

$EXECofs/hwrf_gfs2ofs 

# rewrite all HYCOM atmospheric forcing files so that
# time sampling is uniform for all the forcing files
# not implemented yet ?????

#-hsk: 2011/11/18
$USHofs/ofs_timeinterp_forcing.sh

# End of generating the forcing files

echo "*** Finished script $0"
