#!/bin/ksh
#
# hwrf_rtofs_archv2restart.sh creates a restart file given an archives (as arch.a
#   and arch.b). The new restart file will have the same dimensions (idm,
#   jdm, kdm) as the archive files.
# 

set -x

echo "*** Started script $0"

fixhycom=$FIXhwrf/hwrf-hycom
ln -sf $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.grid.a regional.grid.a
ln -sf $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.grid.b regional.grid.b
ln -sf $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.b regional.depth.b
ln -sf $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.a regional.depth.a

#A Prepare environment

bline=`grep \'baclin\' ${PARMhwrf}/hwrf_${RUNmodIDout}.${gridlabelout}.fcst.blkdat.input | cut -c1-20`
v1=`echo $bline | cut -d\' -f1`
baclin=`echo $v1 | sed "s/       //g"`

# not necessary... will always have the name hwrf_basin.000.b
bfile=hwrf_basin.000.b
afile=hwrf_basin.000.a

#assume spin for 24 hours
#B.2 setup files
  [ -a archv2r_in.a ] && rm -f archv2r_in.a
  ln -sf $afile      archv2r_in.a
  [ -a archv2r_in.b ] && rm -f archv2r_in.b
  ln -sf $bfile      archv2r_in.b

  if [ -s restart_forspin.b ]
  then 
    ln -sf restart_forspin.b restart_in.b
    ln -sf restart_forspin.a restart_in.a
  else  # using a template restart file:
    if [ -s restart_pre.b ]
    then
      ln -sf restart_pre.a restart_in.a
      ln -sf restart_pre.b restart_in.b       
    fi
  fi

#B.3 setup parameter input file

  [ -a archv2restart.in ] && rm archv2restart.in
  [ -a archv2restart.out ] && rm archv2restart.out

cat > archv2restart.in <<EOF
archv2r_in.b
restart_in.a
restart_out.a
20                 'iexpt '   = experiment number x10  (000=from archive file)
3                  'yrflag'   = days in year flag (0=360J16,1=366J16,2=366J01,3=actual)
$idm               'idm   '   = longitudinal array size
$jdm               'jdm   '   = latitudinal  array size
2         'kapref'   = thermobaric reference state (-1 to 3, optional, default 0)
$kdm               'kdm   '   = number of layers
34.0               'thbase' = reference density (sigma units)
$baclin            'baclin' = baroclinic time step (seconds)'
EOF

${EXEChwrf}/hwrf_archv2restart < archv2restart.in

echo "*** Finished script $0"

