#!/bin/ksh
#
#    updates hycom times in forcing files after reading in template files.
#
# -------------------------------------------
# USAGE: hwrf_rtofs_edit_gfsfrctime.sh yyyymmddHH 
# -------------------------------------------
#	PDY	    = yyyymmddHH
#
#---------
# HISTORY:
#---------
#	Edited to use template forcing files to create forcing files
#	that are required to be present 
#	by HYCOM during coupled HWRF-HYCOM run.
#		hy Hyun-Sook Kim 10/3/2014.
#-----------------------------------------------------------------------------

set -x

if [[ $# -ne 1 ]];
then
   echo
   echo " reguires 1 input:"
   echo " ------------------------------------------"
   echo "  hwrf_rtofs_edit_gfsfrctime.sh yyyymmddHH"
   echo " ------------------------------------------"
   exit 1
else
   export PDY=$1
   echo 'CYCLE   = ' ${PDY}
   echo
fi

echo "*** Started script $0"

# --- set paths, if necessary ---
fixhycom=$FIXhwrf/hwrf-hycom

for fvar in airtmp precip presur radflx shwflx surtmp tauewd taunwd vapmix wndspd
do
   
   echo $fvar
   rm -f forcing.$fvar.[ab]

   oA1=hwrf_${RUNmodIDout}.${gridlabelout}.forcing.${fvar}.a
   oB1=hwrf_${RUNmodIDout}.${gridlabelout}.forcing.${fvar}.b

   # --- clean up old files
   ln -sf ${fixhycom}/${oA1} ${oA1}
   cp ${fixhycom}/${oB1} ${oB1}

   # --- prep
   vname=`grep span ${oB1} |head -1 |cut -c1-10`
   prefix=hwrf_${RUNmodIDout}.${gridlabelout}.forcing
   blines=`cat ${oB1} | wc -l`
   num_frames=`grep ${fvar} ${oB1} | wc -l`
   nhead=`expr ${blines} \- ${num_frames}`
   
cat > edit_gfsfrc.in << EOF
$vname
$prefix
$nhead
$num_frames
$PDY
EOF

   # --- run FORTRAN exec
   ${EXEChwrf}/hwrf_rtofs_edit_gfsfrctime < edit_gfsfrc.in

   echo " done for ${fvar} to forcing.${fvar}.[a/b]"

      ((i=i+1))
done

echo "*** Finished script $0"
