#!/bin/ksh
#
# hwrf_rtofs_get_forcing.sh is basically a wrapper
# around the hwrf_ofs_seasforce3.sh script
# 

set -x

echo "*** Started script $0"

if [ $# -eq 6 ]
then
   export srtdate=${1}
   export enddate=${2}
   export intvl=${3}
   export adjust_river=${4}
   export adjust_temp=${5}
   export adjust_wind=${6}

   echo 'srtdate = ' ${srtdate}
   echo 'enddate = ' ${enddate}
   echo 'intvl   = ' ${intvl}
   echo 'adjust_river  = ' ${adjust_river}
   echo 'adjust_temp  = ' ${adjust_temp}
   echo 'adjust_wind  = ' ${adjust_wind}
else
   echo 'Usage: sh hwrf_rtofs_init.sh srtdate enddate intvl adjust_river adjust_temp adjust_wind'
   echo 'NEED SIX INPUT VARIABLES'
   echo 'SCRIPT WILL EXIT'
   exit 1
fi
##############################################################


# --------------------------------------------------------------------------- #
# create forcing files for the coupled forecast step
#
  export EXECofs=$EXEChwrf
  export USHofs=$USHhwrf/hycom
  export USHhwrf=$USHhwrf/hycom
  fixhycom=$FIXhwrf/hwrf-hycom

# determine what needs to be done 
  blkdatfile=$PARMhwrf/hwrf_${RUNmodIDout}.${gridlabelout}.fcst.blkdat.input
  priver=`grep priver $blkdatfile|cut -f1 -d"'"`
  flxflg=`grep flxflg $blkdatfile|cut -f1 -d"'"`
  wndflg=`grep wndflg $blkdatfile|cut -f1 -d"'"`
  atpflg=`grep atpflg $blkdatfile|cut -f1 -d"'"`
  forcingfilesmade=-1

# Atmospheric file forcing file generation
  if [[ $flxflg -eq 0  && $wndflg -eq 0 && $atpflg -eq 0 ]]
  then
     echo "No atmospheric forcing created"
  else
    forcingfilesmade=0
    echo "Creating atmospheric forcing"
#    ln -sf  $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.grid.a regional.grid.a
#    ln -sf  $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.grid.b regional.grid.b
#    ln -sf  $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.a regional.depth.a
#    ln -sf  $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.a regional.mask.a
#    ln -sf  $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.b regional.mask.b

# Get parameter data for seasforce

    cp $fixhycom/ofs_atl.ismus_msk384x190.dat ismus_msk384x190.dat
    cp $fixhycom/ofs_atl.ismus_msk512x256.dat ismus_msk512x256.dat
    cp $fixhycom/ofs_atl.ismus_msk768x384.dat ismus_msk768x384.dat
    cp $fixhycom/ofs_atl.ismus_msk1152x576.dat ismus_msk1152x576.dat
    cp $fixhycom/ofs_atl.ismus_msk1760x880.dat ismus_msk1760x880.dat
    cp $fixhycom/ofs_atl.ismus_msk3072x1536.dat ismus_msk3072x1536.dat

    for rel in 1760x880 3072x1536
    do
       if [ -s ismus_msk${rel}.dat ]
       then
          echo "File ismus_msk${rel}.dat copied"
       else
          msg1="Missing Parameter data for Seasfore"
          msg2="ABNORMAL EXIT NOWCAST: NO FILE for ismus_msk${rel}.dat"
          postmsg "$jlogfile" "$msg1" "$msg2"
          err=2;
          export err;err_chk
       fi
    done

# Create Forcing files 
    $USHhwrf/hwrf_ofs_seasforce3.sh $srtdate $enddate

# correct air temperature over ice.
    if [ $adjust_temp -ne 0 ]
    then
      data=$DATA
      DATA=$workdir
      $USHhwrf/ofs_correct_forcing.sh
      DATA=$data
    else
      echo "Corrections to air Temp is not employed"
    fi
  fi

# Get river forcing files
# determine if river forcing is needed (priver in blkdat file)

  if [ $priver -ne 0 ]
  then

    ln -s  $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.forcing.rivers.a forcing.rivers.a
    ln -s  $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.forcing.rivers.b forcing.rivers.b

    if [ $adjust_river -ne 0 ] 
    then
       $USHhwrf/ofs_create_river.sh
    fi

    if [ -s forcing.rivers.a -a forcing.rivers.b ]
    then
!        cp $fixhycom/hwrf_$RUNmodIDout_$gridlabelout.forcing.rivers.a forcing.rivers.a
!        cp $fixhycom/hwrf_$RUNmodIDout_$gridlabelout.forcing.rivers.b forcing.river.b
        echo "Station River Forcing Files copied"
        forcingfilesmade=0
    else
        msg1="Missing River Forcing Files"
        msg2="ABNORMAL EXIT NOWCAST: NO FILE for forcing.rivers.a or .b "
        postmsg "$jlogfile" "$msg1" "$msg2"
        err=911;
        export err;err_chk
    fi
  else
    echo "River Forcing Files are not employed"
  fi

  if [ $adjust_wind -gt 0 ]
  then
     $USHhwrf/hwrf_ofs_windforcing.sh
     if [ $adjust_wind -gt 1 ]
     then
       mv forcing.wndspd.a forcing.wndspd.a.original
       mv forcing.wndspd.b forcing.wndspd.b.original
       mv forcing.tauewd.a forcing.tauewd.a.original
       mv forcing.tauewd.b forcing.tauewd.b.original
       mv forcing.taunwd.a forcing.taunwd.a.original
       mv forcing.taunwd.b forcing.taunwd.b.original
       mv forcing.wdspd1.a forcing.wndspd.a
       mv forcing.wdspd1.b forcing.wndspd.b
       mv forcing.tauew1.a forcing.tauewd.a
       mv forcing.tauew1.b forcing.tauewd.b
       mv forcing.taunw1.a forcing.taunwd.a
       mv forcing.taunw1.b forcing.taunwd.b
    fi
  fi

# --------------------------------------------------------------------------- #

echo "*** Finished script $0"
exit $forcingfilesmade

