#!/bin/ksh
#
# hwrf_rtofs_init2 - create forcing for Coupled Forecast
#

set -x

echo "*** Started script $0"

##### SET DATE AND OTHER ENVIRONMENTAL VARIABLE FROM THE SUPER SCRIPT #######
##### GET THE INPUT VARIABLES

if [ $# -eq 6 ]
then
   export DOMAIN=${1}
   export YEAR=${2}
   export MONTH=${3}
   export DATE=${4}
   export CYCLE=${5}
   export STORMID=${6}

   echo 'DOMAIN  = ' ${DOMAIN}
   echo 'YEAR    = ' ${YEAR}
   echo 'MONTH   = ' ${MONTH}
   echo 'DATE    = ' ${DATE}
   echo 'CYCLE   = ' ${CYCLE}
   echo 'STORMID = ' ${STORMID}
else
   echo 'Usage: sh hwrf_rtofs_init.sh DOMAIN YEAR MONTH DATE CYCLE STORMID'
   echo 'NEED SIX INPUT VARIABLES'
   echo 'SCRIPT WILL EXIT'
   exit 1
fi

##############################################################
export pdy=$YEAR$MONTH$DATE
export cyc=$CYCLE
export LCASE_NAME=`echo  $DOMAIN | tr '[A-Z]' '[a-z]' `
name=$LCASE_NAME

echo 'pdy      = ' ${pdy}
echo 'cyc      = ' ${cyc}
echo 'name     = ' ${name}
export prevcycle=`${utilexec}/ndate -6 $YYYY$MM$DD$CYC`
cycm1=`echo $prevcycle | cut -c9-10`
secs=${C_NSECS:-$fsecs}
let forecast_hours=$secs/3600
enddate=`${utilexec}/ndate $forecast_hours $YEAR$MONTH$DATE$CYC`
if [ "$OCEAN_staged" == YES ]
then
  OCEAN_full=$STAGE_DIR/$STORMID/$YEAR$MONTH$DATE$CYCLE/OCEAN
  if [[ -d $OCEAN_full &&
        -d $OCEAN_full/forcing &&
        -d $OCEAN_full/nest &&
        -d $OCEAN_full/restarts ]]
  then
     echo $OCEAN_full
     echo is present and assumed to be populated by rtofs_init

     exit 0
  fi
fi

  # ocean initial and boundary conditions were formed:
  # prepare forcing files to model to will run coupled

  #################################################################################
  # 3. FORCING FILES

  # option - 1. update dates from template forcings (which is applicable for hurricane-ocean coupling)
  #          2. create forcing files for the coupled forecast step (6 days?)
  # adjust_river - call ofs_create_river.sh to update climatology river with USGS data.
  # adjust_temp - call ofs_correct_forcing.sh
  # adjust_wind - run parametric wind algorithm, =1 create them, =2 use them

  adjust_wind=0		# always 0 for coupled run

  interval=${interval:-3}
  adjust_river=${adjust_river:-0}
  adjust_temp=${adjust_temp:-0}
  adjust_wind=${adjust_wind:-0}
  export mode=${mode:-fcst}
  export FORCING_TASKS=1

  mkdir ${DATA}/forcing
  cd ${DATA}/forcing
  $utilscript/setup.sh

  # --- flag for using template forcing files.
  usefrc=${usefrc:-0}
  usefrc=0

  if [[ $usefrc -eq 1 ]];
  then
     $USHhwrf/hwrf_rtofs_edit_gfsfrctime.sh $PDY$CYC 
     scriptrc=$?
  else
     $USHhwrf/hwrf_rtofs_get_forcing.sh $PDY$CYC $enddate $interval $adjust_river $adjust_temp $adjust_wind
     scriptrc=$?
  fi
  if [ $scriptrc -eq 0 ]
  then
     mkdir -p ${CSTREAM}/OCEAN/forcing
     cp -p forcing.*.? ${CSTREAM}/OCEAN/forcing
     echo "forcing.complete" > $CSTREAM/init/forcing/forcing.complete
  fi


