#!/bin/ksh
# 
# this script will create gribs from rtofs archive files
# 
set -xa

echo "*** Started script $0"

. $COMhwrf/$stormlabel.holdvars.txt
. $COMOUT/$out_prefix.hycom_settings

export storm=`echo ${STORM} | tr '[A-Z]' '[a-z]'`
export tcid=`echo ${STORMID} | tr '[A-Z]' '[a-z]'`

env

DATA=$WORKhwrf/hycompost
mkdir -p $DATA
cd $DATA

export utilscript=$utilexec/../ush
export NDATE=$utilexec/ndate
export NHOUR=$utilexec/nhour
fixhycom=$FIXhwrf/hwrf-hycom
export COMOUT=$COMhwrf


#############################################################

# source ocean_status file and set parms for mld files
# . $COMOUT/ocean_status.${STORM}${STORMID}.${YYYYMMDDHH}
k1=1
k2=15
tdiff=0.5
rdiff=0.1
tiso=26.0
nav="9.999e20"
pref=0.0;     # Global HYCOM

ln -sf ${fixhycom}/hwrf_${RUNmodIDout}.${gridlabelout}.regional.grid.b     regional.grid.b
ln -sf ${fixhycom}/hwrf_${RUNmodIDout}.${gridlabelout}.regional.grid.a     regional.grid.a
ln -sf ${fixhycom}/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.b    regional.depth.b
ln -sf ${fixhycom}/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.a    regional.depth.a

# flags
export std_grib=NO     # implement this later (if necessary)
export volume_3d=YES
export surface_d=YES
export volume_3z=YES
export surface_z=NO

# endhours 
ENDHOUR=126
export gridno=120

# Waiting time (in 10 sec)
icnt_max=180

typeset -Z3 LEAD
LEAD=000
export cLEAD=0

while [[ $cLEAD -le $ENDHOUR ]]
do
  ymdh=`$utilexec/ndate $cLEAD ${YMDH}`
  fyr=`echo $ymdh | cut -c1-4`
  fmo=`echo $ymdh | cut -c5-6`
  fdy=`echo $ymdh | cut -c7-8`
  fhr=`echo $ymdh | cut -c9-10`
  fymd=`echo $ymdh | cut -c1-8`
  fyyyyddd=`$utilscript/date2jday.sh $fymd`
  fddd=`echo $fyyyyddd | cut -c5-7`
  LEAD=$cLEAD

  export yyyy=`echo $YMDH|cut -c1-4`
  export mm=`echo $YMDH|cut -c5-6`
  export dd=`echo $YMDH|cut -c7-8`
  export cyc=`echo $YMDH|cut -c9-10`
  
  art=archv.${fyr}_${fddd}_${fhr}
  # get 0th ab file from boundary condition
  ryyyyddd=`$utilscript/date2jday.sh $YMDH`
  ddd=`echo $ryyyyddd | cut -c5-7`

  #
  # following is copying F000 archive to runwrf dir 
  # for post processing
  if [ $cLEAD -eq 0 ]
  then
    if [ -e $WORKhwrf/hycominit/${art}.a ]
    then
	cp $WORKhwrf/hycominit/${art}.a $WORKhwrf/runwrf/${art}.a
    	cp $WORKhwrf/hycominit/${art}.b $WORKhwrf/runwrf/${art}.b
    	cp $WORKhwrf/hycominit/${art}.log $WORKhwrf/runwrf/${art}.log 
#  	echo "this file exists" > ../hycompost/archv.${YEAR}_${ddd}_${cyc}.log
    else
        cp ${COMhwrf}/${storm}${tcid}.${YMDH}.spin_archv.a ${WORKhwrf}/runwrf/${art}.a
        cp ${COMhwrf}/${storm}${tcid}.${YMDH}.spin_archv.b ${WORKhwrf}/runwrf/${art}.b
        echo "use spin_archv instead" > ../archv.${YEAR}_${ddd}_${cyc}.log
    fi
  fi

  # wait for the new forecast output to be available:
  icnt=1
  while [ $icnt -lt $icnt_max ]
  do
    if [ -s $WORKhwrf/runwrf/${art}.log ]
    then
      break
    fi

    print Sleeping $icnt times while waiting for $WORKhwrf/runwrf/${art}.log
    sleep 10
    icnt=$((icnt + 1))
  done

  if [ $icnt -ge $icnt_max ]
  then
    echo Post timed out, $WORKhwrf/runwrf/${art}.log not available after $icnt_max iterations.
    exit -203
  fi

##########################################

  afile=$WORKhwrf/runwrf/${art}.a
  bfile=$WORKhwrf/runwrf/${art}.b

  cp $afile $COMOUT/hwrf_${RUNmodIDout}.t${cyc}z.${fyr}_${fddd}_${fhr}.a
  cp $bfile $COMOUT/hwrf_${RUNmodIDout}.t${cyc}z.${fyr}_${fddd}_${fhr}.b

  ln -sf $afile archv.a
  ln -sf $bfile archv.b

#create lat,lon gribs for p,u,v grids to append to grib file
cat > fort.22 << EOF
1 1 $idm $jdm
EOF
cat > for_latlon<<EOF
$yyyy $mm $dd $cLEAD $cyc 0.0 0.0 120
EOF
$EXEChwrf/ofs_latlon <for_latlon
cat ugrib > latlon.grb
cat vgrib >> latlon.grb
cat pgrib >> latlon.grb
rm -f ugrib vgrib pgrib

  rem=$(($fhr%6))
  
  if [ $rem -eq 0 ]
  then
    if [ $volume_3z = YES ]
    then
      infile=$PARMhwrf/hycom/hwrf_${RUNmodIDout}.archv2data_3z.in
      executable=$EXEChwrf/hwrf_ofs_archv2data3z
      outfile=${storm}${tcid}.${RUNmodIDout}_3z.${YMDH}.F${LEAD}
      rm -f fort.51
      $USHhwrf/hycom/rtofs_3zit.sh
      if [ -s $outfile ]
      then
        procstatus=0
      else
        procstatus=1
      fi
    fi
    cp ${outfile}.a ${COMOUT}/${outfile}.a
    cp ${outfile}.b ${COMOUT}/${outfile}.b

    if [ $volume_3d = YES ]
    then
      infile=$PARMhwrf/hycom/hwrf_${RUNmodIDout}.archv2data_3d.in
      executable=$EXEChwrf/hwrf_ofs_archv2data2d
      outfile=${RUNmodIDout}.t${cyc}z.F${LEAD}.3d.grb
      rm -f fort.51
      $USHhwrf/hycom/ofs_gribit.sh
      if [ -s $outfile ]
      then
        procstatus=0
        cat latlon.grb >> $outfile
      else
        procstatus=1
      fi
      cp $outfile ${COMOUT}/${outfile}

      # create mld from 3d volume grib
      # -- old (y2012): echo "$idm $jdm $k1 $k2 $nav $tdiff $rdiff $tiso " > get_layers.in
      # -- new (y2012): add salinity to compute OHC requires Pref (0.0)

      echo "$idm $jdm $k1 $k2 $nav $tdiff $rdiff $tiso $pref " > get_layers.in

      num=1
      while (( ${num} <= $k2 ))
      do
         nump=${num}
         num=$(( $num + 1 ))
         lay="$nump-$num:"
         for int in LAYTH WTMPC DEN 
         do
            fld=${int}$num
            file_out=mld${STID}.${fdy}${fhr}_${fld}_${cLEAD}.dat
            $utilexec/wgrib ${outfile} | grep ${int} | grep ${lay} | $utilexec/wgrib ${outfile} -i -text -o ${file_out}
         echo ${file_out} >> get_layers.in

         done #fld
         #${int}==MIXHT ]; then
         int=MIXHT
         fld=${int}$num
         file_out=mld${STID}.${fdy}${fhr}_${fld}_${cLEAD}.dat
         $utilexec/wgrib ${outfile} | grep ${int} | $utilexec/wgrib ${outfile} -i -text -o ${file_out}
         echo ${file_out} >> get_layers.in

      done #num
      $EXEChwrf/hwrf_get_layers < get_layers.in >> get_layers.out
      typeset -Z3 layLEAD
      layLEAD=000
      layLEAD=$cLEAD
      mv fort.21 ${COMOUT}/hwrf_mld.${STID}.${YMDH}_F${layLEAD}.bin

    fi
  fi

  if [ $surface_z = YES ]
  then
    infile=$PARMhwrf/hycom/hwrf_${RUNmodIDout}.archv2data_2z.in
    if [ $rem -eq 0 ]
    then
      # create infile with kdm=$kdm for volume files but output is surface
      if [ ! -s hwrf_${RUNmodIDout}.archv2data_2z.in.$kdm ]
      then
        kdmline=`grep kdm $PARMhwrf/hycom/hwrf_${RUNmodIDout}.archv2data_2z.in`
        kdmvalue=`echo $kdmline|cut -d\' -f1`
        sed -e "/$kdmline/s/$kdmvalue/$kdm/" $PARMhwrf/hycom/hwrf_${RUNmodIDout}.archv2data_2z.in > hwrf_${RUNmodIDout}.archv2data_2z.in.$kdm
      fi
      infile=hwrf_${RUNmodIDout}.archv2data_2z.in.$kdm
    fi
    executable=$EXEChwrf/hwrf_ofs_archv2data2d_insitu
    outfile=${RUNmodIDout}.t${cyc}z.f${LEAD}.grb
    rm -f fort.51
    $USHhwrf/hycom/ofs_gribit.sh
    if [ -s $outfile ]
    then
      procstatus=0
      cat latlon.grb >> $outfile
    else
      procstatus=1
    fi
  fi
  if [ $surface_d = YES ]
  then
    infile=$PARMhwrf/hycom/hwrf_${RUNmodIDout}.archv2data_2d.in
    if [ $rem -eq 0 ]
    then
      # create infile with kdm=$kdm for volume files but output is surface
      if [ ! -s hwrf_${RUNmodIDout}.archv2data_2d.in.$kdm ]
      then
        kdmline=`grep kdm $PARMhwrf/hycom/hwrf_${RUNmodIDout}.archv2data_2d.in`
        kdmvalue=`echo $kdmline|cut -d\' -f1`
        sed -e "/$kdmline/s/$kdmvalue/$kdm/" $PARMhwrf/hycom/hwrf_${RUNmodIDout}.archv2data_2d.in > hwrf_${RUNmodIDout}.archv2data_2d.in.$kdm
      fi
      infile=hwrf_${RUNmodIDout}.archv2data_2d.in.$kdm
    fi
    executable=$EXEChwrf/hwrf_ofs_archv2data2d
    outfile=${RUNmodIDout}.t${cyc}z.f${LEAD}.3d.grb
    rm -f fort.51
    $USHhwrf/hycom/ofs_gribit.sh
    if [ -s $outfile ]
    then
      procstatus=0
      cat latlon.grb >> $outfile
    else
      procstatus=1
    fi
    cp $outfile ${COMOUT}/.
  fi
  let cLEAD=cLEAD+1
done

cp ${WORKhwrf}/runwrf/blkdat.input ${COMOUT}/.

#------ final stage ------------------------------------------------------
# cp restart files to COMOUT
# 6 hour restart file
#cp ../restart_outR.a $COMOUT/hwrf_${RUNmodIDout}.t${cyc}z.nest_restartR.a
#cp ../restart_outR.b $COMOUT/hwrf_${RUNmodIDout}.t${cyc}z.nest_restartR.b
# last restart file
#cp ../restart_out.a $COMOUT/hwrf_${RUNmodIDout}.t${cyc}z.nest_restart.a
#cp ../restart_out.b $COMOUT/hwrf_${RUNmodIDout}.t${cyc}z.nest_restart.b

############################################################################
# Postprocessing - graphics
############################################################################
#
#-------------------------------------------------
#   will be done by Python scripts ... (hsk)
#
# Create a set of 
#	1. SST+sfc-Currents; 
#       2. MLD+mldCurrents; 
#       3. Footprint SST
#-------------------------------------------------

exit
# below this will work only on wcoss

graphic=/marine/save/Hyun.Sook.Kim/air-sea-hwrf/graphics/PyHYCOM

#python $graphic/hycom_sfc.py $YMDH $storm $tcid ${EXPT} $RUNmodIDout
#python $graphic/subsfc_binary.py $YMDH $storm $tcid ${EXPT} $RUNmodIDout
#python $graphic/MLDchange.py $YMDH $storm $tcid ${EXPT} $RUNmodIDout
#python $graphic/SSTcooling.py $YMDH $storm $tcid ${EXPT} $RUNmodIDout
#python $graphic/Fluxfootprint.py $YMDH $storm $tcid ${EXPT} $RUNmodIDout
#python $graphic/Wvel2D.py $YMDH $storm $tcid ${EXPT} $RUNmodIDout
_
# final checking: for complete deposit outputs to COMOUT
# keep blkdat.input
cp ../runwrf/blkdat.input ${COMOUT}/.
mv *[Ff]*.grb *.bin ${COMOUT}/.

# --- archive subset for post-processing
#tar -cvf ${COMOUT}/../../${RUNmodIDout}${STID}${YYYYMMDDHH}.tar *rtofs*.F*.3d.grb *mld*bin ${COMOUT}/*hwrfprs_n.grb* ${COMOUT}/*atcfunix

#-------------------------- END of SCRIPT
echo 'SUCCESSFUL COMPLETION OF POST PROCESSING SCRIPT hwrf_rtofs_post.sh' 
