#!/bin/ksh
#
#  Produces ctl and idx files for each grib file.
#  
# ------
#  7/11/2012 Hyun-Sook Kim
#------------------------------------
set -x

echo "*** Started script $0"

#0 #### GET THE INPUT VARIABLES

if [ $# -eq 3 ]
then
    export PDY=${1}
    export storm=${2}
    export tcid=${3}

    echo 'PDY = ',${PDY}
    echo 'storm = ',${storm}
    echo 'tcid = ',${tcid}
else
   echo '    Usage: sh hwrf_rtofs_post4grads.sh PDY storm tcid'
   echo '    NEED THREE INPUT VARIABLES'
   echo '    SCRIPT WILL EXIT'
   exit 1
fi
##############################################################
#
export grb2ctl=/home/Hyun.Sook.Kim/util/grib2ctl.pl

# 1. set working directory

export CYC=`echo $PDY | cut -c9-10`
echo $CYC
export TCID=`echo $tcid | tr '[a-z]' '[A-Z]'`
echo $TCID
export STORM=`echo ${storm} | tr '[a-z]' '[A-Z]'`
echo $STORM
export STORMID=${STORM}${TCID}
echo $STORMID

USHwrf=/scratch2/portfolios/NCEPDEV/marine/save/wx20hk/HyHWRFv2/ush/
FIXwrf=/scratch2/portfolios/NCEPDEV/marine/save/wx20hk/HyHWRFv2/fix/
ptmp2=//scratch2/portfolios/NCEPDEV/ptmp/Hyun.Sook.Kim/
COM=$ptmp2/hwrf/com/$PDY/${tcid}/

ocean_status=${COM}/ocean_status.${STORMID}.${PDY}
export RUNmodIDout=`grep RUNmodIDout $ocean_status | cut -d"=" -f2`
export gridlabelout=`grep gridlabelout $ocean_status | cut -d"=" -f2`
export idm=`grep idm $ocean_status | cut -d"=" -f2`
export jdm=`grep jdm $ocean_status | cut -d"=" -f2`

echo ${RUNmodIDout}
echo ${gridlabelout}
echo $idm 
echo $jdm

bfile=hwrf_${RUNmodIDout}.${gridlabelout}.regional.grid.b
export lonmin=`grep plon ${FIXwrf}/$bfile | cut -d" " -f7`

export latmin=`grep plat ${FIXwrf}/$bfile | cut -d" " -f7`

xdefl=`echo xdef $idm linear $lonmin 0.08333`
ydefl=`echo ydef $jdm linear $latmin 0.08333`

echo $xdefl


#--- HYCOM outputp
typeset -Z2 CYC

typeset -Z3 iknt
iknt=001

while [ $iknt -le 126 ]
do
   
   prefix=hwrf_${STORM}.${tcid}.${RUNmodIDout}.t${CYC}z.f$iknt
   gfile=$prefix.3d.grb

   $grb2ctl -raw ${COM}/$gfile > tmpctl

   wholelinex=`grep xdef tmpctl | cut -c1-30`
   linex=`grep xdef tmpctl | cut -c1-16`
   wholeliney=`grep ydef tmpctl | cut -c1-30`
   liney=`grep ydef tmpctl | cut -c1-16`
   newlinex="$linex $lonmin 0.08333"
   newliney="$liney $latmin 0.08333"

   echo x $linex .... $newlinex
   echo y $liney .... $newliney
   sed -e "/$linex/s/$wholelinex/$newlinex/" tmpctl > tmpxxx
   sed -e "/$liney/s/$wholeliney/$newliney/" tmpxxx > ${COM}/$gfile.ctl
   rm -f tmpxxx

   # create index file for ctl
   gribmap -i ${COM}/$gfile.ctl

   # increatment
   iknt=$((iknt + 1))
done


