#!/bin/ksh
#
#  hwrf_rtofs_restart2restart.sh
#       1. subregion rtofs_glo.t00z.n00.restart.[ab] to hurricane subdomains.
#       2. using rtofs_subset exec.
#
#
#  Note: remove 5 temp b-files, except _org: 
#	_tailoff, _mnmx, _header, _body, _label
#
#--------
# history
#--------
#   7/5/2011 Hyun-Sook Kim: Modified 'subregion_field.com' to suit for RTOFS 
#            

set -x
echo "*** Started script $0"

#---------------------------------------------------------------

# prestart passed in by calling program (spin)
prestart=$1

#--- gridlabel:
# Atl: HATe0.08(hat13.east), HATm0.08 (hat12.mid), HATw0.08(hat11.west), HATn0.08(hat14.north)
# E.Pac: HEPe0.08(hep23.east), HEPm0.08(hep22.mid), HEPw0.08(hep21.west)
# W.Pac: HWPe0.08(hwp32.east), HWPw0.08(hwp31.west), HWPn0.08(hwp33.north)

idmglobal=`sed -n 1,1p regional.grid.b | awk '{printf $1}'`
jdmglobal=`sed -n 2,2p regional.grid.b | awk '{printf $1}'`

# dan: need to use infile to replace standard in and standard out.

#---
#--- subsetting a parent restart file:
${EXEChwrf}/hwrf_rtofs_restart2restart ${prestart}.a $idmglobal $jdmglobal $ic $jc $idm $jdm restart.${YMDH}.${gridlabelout}.a > restart.${YMDH}.${gridlabelout}.b.one

# dan: all this file manipulation of the b-file should be done in the fortran code.

#---
#--- format subsetted restart.*_org.b file:
# nc: # of columns for a set of variable names
# wcb: # of a total lines of restart*.b (final & parent restart b-file)
# twc: # of lines of restart.*_org.b 
nc=38
wcb=341
twc=339

#--- restart_org.b has 2 extra lines at the end of file, and remove them:
head -$twc restart.${YMDH}.${gridlabelout}.b.one > restart.${YMDH}.${gridlabelout}_tailoff.b

#--- REFORMATTING THE NESTED RESTART B-FILE:
# 1. get header:
head -2 ${prestart}.b  > restart.${YMDH}.${gridlabelout}_head.b 

# 2. reformat the stats columns:
cat restart.${YMDH}.${gridlabelout}_tailoff.b | awk '{printf ("%16.7E%16.7E\n", $4, $5)}' > restart.${YMDH}.${gridlabelout}_mnmx.b

# 3. get a set of variable names from the parent restart b-file:
cut -c 1-${nc} ${prestart}.b  | tail -${twc} > restart.${YMDH}.${gridlabelout}_label.b

# 4. paste 2 b-files: 1. var-names; 2. min/max stats:
paste -d ' ' restart.${YMDH}.${gridlabelout}_label.b restart.${YMDH}.${gridlabelout}_mnmx.b > restart.${YMDH}.${gridlabelout}_body.b

# 5. concatenate 2 b-files: 1. header; 2. min/max stats:
cat restart.${YMDH}.${gridlabelout}_head.b restart.${YMDH}.${gridlabelout}_body.b > restart.${YMDH}.${gridlabelout}.b

# 6. checking # of total lines of the final restart b-file:
#check=`wc -l restart.${YMDH}.${gridlabelout}.b
check=`awk -F, 'END{print NR}' restart.${YMDH}.${gridlabelout}.b`

echo " "
echo " 		number of lines: $check (cf. $wcb)"
echo " "

if [ $check -eq $wcb ]
then

#   ls -ld  $CSTREAM/OCEAN/restarts

mv restart.${YMDH}.${gridlabelout}.a restart_pre.a
mv restart.${YMDH}.${gridlabelout}.b restart_pre.b

   echo "--- hwrf_rtofs_restart2restart.sh ---"
   echo " 	Successful"

#dan keep trail
#   rm -rf restart.${PDY}.${gridlabelout}_*.b

else
   echo "--- hwrf_rtofs_restart2restart.sh ---"
   echo "	Failed"
fi

echo "*** Finished script $0"

