#!/bin/ksh
#
# hwrf_rtofs_spin.sh runs a nowcast run for "spinlength" hours.
# 

set -x
echo "*** Started script $0"

#-----------------------------------
#A Prepare environment
#A.1 set up macros

fixhycom=$FIXhwrf/hwrf-hycom

# Set up the start time and end time for the forecast

#A.2 find data from previous cycle
export spinlength=${spinlength:-24}
spinstart=`$utilexec/ndate -$spinlength $YMDH`
sday=`$utilscript/date_normal2hycom.sh $spinstart`
cm1=`echo $spinstart | cut -c9-10`

eday=`$utilscript/date_normal2hycom.sh $YMDH`
echo "  $sday $eday false false  " > limits

# FIND RESTART FILE FOR SPIN::::

# if warm start, then restart is in oldcom
oldcom=`grep ^oldcom $COMhwrf/storm?.conf|cut -d" " -f3`
prevcycle=`${utilexec}/ndate -6 $YMDH`
out_prefix_prefix=`echo $out_prefix | cut -d. -f1`
restart_for_spin=$oldcom/$out_prefix_prefix.$prevcycle.${RUNmodIDout}.spin_restart

if [[ -s ${restart_for_spin}.a && -s ${restart_for_spin}.b ]]
then
   ln -s ${restart_for_spin}.a restart_in.a
   ln -s ${restart_for_spin}.b restart_in.b
else
   echo "Creating Restart Files via 2 ways (now) and 3 ways, if DA framework installed"
#from init

#cold start... order of preferred restarts
       RTOFSDIR=./RTOFSDIR
       YMDHm1=`$utilexec/ndate -24 $YMDH`
       PDY=`echo $YMDH | cut -c1-8`
       PDYm1=`echo $YMDHm1 | cut -c1-8`
       prestart1=$RTOFSDIR/rtofs.$PDYm1/${RUNmodIDin}.t00z.n00.restart
       prestart2=$RTOFSDIR/rtofs.$PDY/${RUNmodIDin}.t00z.n-48.restart
       prestart3=$RTOFSDIR/rtofs.$PDY/${RUNmodIDin}.t00z.n00.restart

       prestart1=$RTOFSDIR/rtofs_${PDY}_000000_restart
       prestart2=/dev/null
       prestart3=/dev/null

       foundrestart=0

       if [[ -s ${prestart1}.a && -s ${prestart1}.b ]]
       then
          foundrestart=1
          prestart=$prestart1
       fi

       if [[ -s ${prestart2}.a && -s ${prestart2}.b && $foundrestart -eq 0 ]]
       then 
          foundrestart=1
          prestart=$prestart2
       fi

       if [[ -s ${prestart3}.a && -s ${prestart3}.b && $foundrestart -eq 0 ]]
       then
          foundrestart=1
          prestart=$prestart3
       fi

       if [ $foundrestart -eq 0 ]
       then
         msg="ABNORMAL EXIT HURRICANE SPIN: NO RESTART FILE FOUND" 
       fi

       # run restart2restart:  (if right time, use it, else just use pbot,psikk,thkk)
       $USHhwrf/hycom/hwrf_rtofs_restart2restart.sh $prestart
       dtime=`sed -n 2,2p restart_pre.b |awk '{print $5}'`
       ryd=`sh $utilscript/date_hycom2normal.sh $dtime`
 
       if [ $ryd -eq $spinstart ]
       then # have restart from global.. can use that
          mv restart_pre.a restart_forspin.a
          mv restart_pre.b restart_forspin.b
  
       else # don't have right restart, so get restart from archive (and pbot,psikk,thkk from restart)
         $USHhwrf/hycom/hwrf_rtofs_archv2restart.sh -$spinlength
         mv restart_out.a restart_forspin.a
         mv restart_out.b restart_forspin.b
       fi  # spinstart
       ln -sf restart_forspin.a restart_in.a
       ln -sf restart_forspin.b restart_in.b
fi # yes/no for restart_for_spin.

#A.3 set up  topography (rm global domains)
[ -a regional.grid.a ] && rm -f regional.grid.a
[ -a regional.grid.b ] && rm -f regional.grid.b
[ -a regional.depth.a ] && rm -f regional.depth.a
[ -a regional.depth.b ] && rm -f regional.depth.b
[ -a regional.mask.a ] && rm -f regional.mask.a
[ -a regional.mask.b ] && rm -f regional.mask.b

ln -s  $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.grid.a regional.grid.a
ln -s  $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.grid.b regional.grid.b
ln -s  $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.b regional.depth.b
ln -s  $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.a regional.depth.a
# note: get mask from the regional.depth 
ln -s -f $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.a regional.mask.a
ln -s -f $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.b regional.mask.b

# --------------------------------------------------------------------------- #

# --------------------------------------------------------------------------- #
# Get boundary conditions (relax files)

ln -s -f $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.relax.rmu.a relax.rmu.a
ln -s -f $fixhycom/hwrf_${RUNmodIDout}.${gridlabelout}.relax.rmu.b relax.rmu.b

# --------------------------------------------------------------------------- #
# create forcing files for the spin forecast step (default 6 hours)
# adjust_wind - call ofs_create_river.sh to update climatology river with USGS data
# adjust_temp - call ofs_correct_forcing.sh
# adjust_wind - run hsk wind algorithm, =1 create them, =2 use them
#
#-- hsk's doing
 adjust_wind=${parameterized_winds:-0}

interval=${interval:-1}
adjust_river=${adjust_river:-0}
adjust_temp=${adjust_temp:-0}
adjust_wind=${adjust_wind:-2}
# make this an analysis 
export mode=${mode:-anal}

#-- hsk's doing
forcingfilesmade=${forcingfilesmade:-0}

if [[ ${forcingfilesmade} -eq 1 ]]; 
then
    ln -sf ${STAGE_DIR}/${STORMID}/${PDY}${CYC}/OCEAN/forcing/forcing.* .
else
export FORCING_TASKS=$TOTAL_TASKS
echo spinstart $spinstart
echo YMDH $YMDH
$USHhwrf/hycom/hwrf_rtofs_get_forcing.sh $spinstart $YMDH $interval $adjust_river $adjust_temp $adjust_wind
scriptrc=$?
fi

# --------------------------------------------------------------------------- #
# Get initialization files
procs=90
#cp $PARMhwrf/hwrf_${RUNmodIDout}.${gridlabelout}.fcst.blkdat.input.standalone blkdat.input
cp $PARMhwrf/hwrf_${RUNmodIDout}.${gridlabelout}.fcst.blkdat.input.standalone blkdat.input
cp $PARMhwrf/hwrf_${RUNmodIDout}.${gridlabelout}.ports.input ports.input
cp $PARMhwrf/hwrf_${RUNmodIDout}.${gridlabelout}.patch.input.$procs patch.input

# change rstrfq - for spin=.25; for coupled=4.75 

#file=blkdat.input
#flag=rstrfq
#value=0.25

#flgline=`grep \'${flag}\' $file | cut -c1-20`
#v1=`echo $flgline | cut -d\' -f1`
#val=`echo $v1 | sed "s/       //g"`
#if [ $val != $value ]
#then
#  mv $file $file.$$
#  sed -e "/$flgline/s/$val/$value/" $file.$$ > $file
#fi

for fil in blkdat ports patch
do
   if [ -s ${fil}.input ]
   then
      echo "${fil}.input copied"
   else
      msg="ABNORMAL EXIT HURRICANE SPIN: NO FILE for ${fil}.input"
   fi
done

# nest
mkdir nest
for bfile in `ls -1 hwrf_basin.*.b`
do
    filroot=`echo $bfile | cut -d. -f1-2`
    afile=$filroot.a

    modelday=`sed -n 11,11p $bfile | awk '{print $4}'`
    mydh=`sh $utilscript/date_hycom2normal.sh $modelday`
    myd=`echo $mydh | cut -c1-8`
    yd=`$utilscript/date2jday.sh $myd`
    myyyy=`echo $yd | cut -c1-4`
    mddd=`echo $yd | cut -c5-7`
    mhh=`echo $mydh | cut -c9-10`
    ln -s ../$afile  nest/archv.${myyyy}_${mddd}_${mhh}.a
    ln -s ../$bfile  nest/archv.${myyyy}_${mddd}_${mhh}.b
done

# incup
mkdir incup
cd incup
for f in `ls -1 ../nest/archv*a`
do
  d=`echo $f | awk '{print substr ($1, 15,11)}'`
  ln -sf ../nest/archv.${d}.a incupd.${d}.a
  ln -sf ../nest/archv.${d}.b incupd.${d}.b
done
cd ..

# put relax.rmu files in correct format and directory
cp relax.rmu.a ./nest/rmu.a
cp relax.rmu.b ./nest/rmu.b

ln -s $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.forcing.kpar.a forcing.kpar.a
ln -s $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.forcing.kpar.b forcing.kpar.b
ln -s $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.forcing.offlux.a forcing.offlux.a
ln -s $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.forcing.offlux.b forcing.offlux.b
ln -s $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.forcing.rivers.a forcing.rivers.a
ln -s $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.forcing.rivers.b forcing.rivers.b
#note change from _ to .
# note addendum -- fix file relax_ssh renamed to relax.ssh
ln -s $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.relax.ssh.a relax.ssh.a
ln -s $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.relax.ssh.b relax.ssh.b
ln -s $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.veldf2.a veldf2.a
ln -s $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.veldf2.b veldf2.b

# relaxation files:
ln -s  $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.relax.temp.a relax.temp.a
ln -s  $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.relax.temp.b relax.temp.b

ln -s  $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.relax.saln.a relax.saln.a
ln -s  $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.relax.saln.b relax.saln.b

# isobaric
ln -s  $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.tbaric.a tbaric.a
ln -s  $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.tbaric.b tbaric.b

ln -s  $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.iso.sigma.a iso.sigma.a
ln -s  $fixhycom/hwrf_$RUNmodIDout.$gridlabelout.iso.sigma.b iso.sigma.b

# copy executable
cp $EXEChwrf/hwrf_${RUNmodIDout}_forecast ./ocean_executable
cp $EXEChwrf/hwrf_${RUNmodIDout}_forecast hwrf_${RUNmodIDout}_forecast
cp $EXEChwrf/hwrf_${RUNmodIDout}_forecast forecast_exe
#cp $EXEChwrf/hwrf_${RUNmodIDout}_forecast ./ocean_executable

#dan move forcing files to proper name
if [[ -e forcing.surtem.a ]];
then
	mv forcing.surtem.a forcing.surtmp.a
	mv forcing.surtem.b forcing.surtmp.b
fi

rm -f ok

# this done in python....
#${USHhwrf}/hwrf_run.sh ./ocean_executable >> $pgmout
#poe ./ocean_executable -procs $NPROCS_o >> $pgmout 2>errfile

echo "*** Finished script $0"

