#!/bin/ksh
#
# hwrf_subset_rtofs.sh creates small domain archive files with new
#   idm, jdm      sub-region domain size
#   ic,jc         is the i,j starting point in fine grid
#   ijgrid        is the subsampling rate over the fine grid
#   fstart        hours to create BC before PDYcyc
#   fend          hours to create BC after PDYcyc
#
 
set -x

echo "*** Started script $0"

fixhycom=$FIXhwrf/hwrf-hycom
PDY=`echo $YMDH | cut -c1-8`

if [ $# -eq 2 ]
then
   before=${1}
   after=${2}
else
   echo 'Usage: hwrf_rtofs_subset_bdry_init.sh  fstart fend'
   echo 'NEED two INPUT VARIABLES'
   msg="ABNORMAL EXIT hwrf_rtofs_subset_bdry_init: NEED two INPUT VARIABLES"
   postmsg "$jlogfile" "$msg"
   err=1;
   export err;err_chk
fi

## -- just set archdir where the rtofs data is (SPINUP?)
## RTOFSDIR or SPINUP needs to be populated first

#2. setup static files in working directory

   ln -sf ${fixhycom}/${RUNmodIDin}.${gridlabelin}.regional.grid.b     regional.grid.b
   ln -sf ${fixhycom}/${RUNmodIDin}.${gridlabelin}.regional.grid.a     regional.grid.a

   ln -sf ${fixhycom}/${RUNmodIDin}.${gridlabelin}.regional.depth.b     regional.depth.b 
   ln -sf ${fixhycom}/${RUNmodIDin}.${gridlabelin}.regional.depth.a     regional.depth.a

   ln -sf ${fixhycom}/hwrf_${RUNmodIDout}.${gridlabelout}.regional.grid.b     regional.subgrid.b
   ln -sf ${fixhycom}/hwrf_${RUNmodIDout}.${gridlabelout}.regional.grid.a     regional.subgrid.a

   ln -sf ${fixhycom}/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.b     regional.subdepth.b
   ln -sf ${fixhycom}/hwrf_${RUNmodIDout}.${gridlabelout}.regional.depth.a     regional.subdepth.a

#3. for each file from startday for forecast_hours (fhours) extract the sub-domain
# collect archive files, putting (likely) volume files together 

ii=1
icount=0
idone='F'
export rtofscycle=t00z
RTOFSDIR=./RTOFSDIR

############################################################################
fstart=`${utilexec}/ndate -$before $YMDH`
fend=`${utilexec}/ndate $after $YMDH`
fstep=$fstart
interval=3
while [ $fstep -le $fend ]
do
  fstep1=`echo $fstep | cut -c1-8`
  fstep2=`echo $fstep | cut -c9-10`
  lsa=`ls -C1 $RTOFSDIR/rtofs_${fstep1}_${fstep2}0000_archv.b`
  farch="$farch $lsa"
  fstep=`${utilexec}/ndate $interval $fstep`
done

############################################################################

#---- hsk: split to 3 steps: 1. link files; 2. run scripts; 
# 6/12/2012
#-------------
# --- Step1: link files
for thefile in $farch
do
  if [ -s ${thefile} ]
  then

    thedir=`dirname $thefile`
    bfile=`basename $thefile`
    rootfile=`echo $bfile | cut -d. -f1-1`
    afile=$rootfile.a

    [ -a archv_in.$icount.a ] && rm -f archv_in.$icount.a
    ln -s ${thedir}/$afile archv_in.$icount.a

    [ -a archv_in.$icount.b ] && rm -f archv_in.$icount.b
    ln -s ${thedir}/$bfile archv_in.$icount.b

    let ' icount=icount+1'
  else
    echo "$thefile does not exist"
  fi
done

# --- Step 2: run scripts
icount=0
for thefile in $farch
do

bfile=`basename $thefile`
# create here-script for mpmd (script output goes to errfile)
cat > subregion.$icount.sh << EOF_1
#!/bin/ksh
set -x
bfile=$bfile
icount=$icount
export pgmout=$pgmout
echo "STARTING \$0 for \$bfile"
let i3=$icount*3
if [ \$i3 -lt 100 ]; then i3=0\${i3}; if [ \$i3 -lt 10 ]; then i3=0\${i3}; fi; fi
Xfile=hwrf_basin.\$i3
Bfile=\${Xfile}.b

[ -a subregion.$icount.in ] && rm subregion.$icount.in
[ -a subregion.$icount.out ] && rm subregion.$icount.out
 
cat > subregion.$icount.in <<EOF_2
archv_in.$icount.b
\$Bfile
subregion $Application
$idm       'idm   ' = longitudinal array size
$jdm       'jdm   ' = latitudinal  array size
$ic        'irefi ' = 1st index origin of subgrid or 0 if NOT aligned
$jc        'jrefi ' = 2nd index origin of subgrid
1          'irefo ' = longitude output reference location
1          'jrefo ' = latitude output reference location
0          'iceflg' = ice in output archive flag (0=none,1=energy loan model)
EOF_2

sdate=\`date '+%Y%m%d %T'\`
echo DEBUG starting subregion \$Xfile \$sdate
case $ijgrid in 
   1)
     ${EXEChwrf}/hwrf_rtofs_subregion < subregion.$icount.in > subregion.$icount.out
      ;;
   2)
     ${EXEChwrf}/hwrf_isubregion2avg < subregion.$icount.in > subregion.$icount.out
      ;;
   *)
      echo "*** $0 bad ijgrd number \$ijgrid ***"
esac

sdate=\`date '+%Y%m%d %T'\`
echo DEBUG done subregion, \$Xfile \$sdate

EOF_1
# end here-script for mpmd
chmod 744 subregion.$icount.sh
let icount=icount+1
done

# Step 3: run the subregions in the background
j=0
while [ $j -lt $icount ]
do
   ./subregion.$j.sh &
   let j=j+1
done
wait

echo "*** Finished script $0"

