#!/bin/sh
set -x
#
#########################################################################
# Usage: ofs_timeinterp_forcing.sh                                      #
#                                                                       #
# Description: Create forcing files with synchronous sampling times.    #
#                                                                       #
# History:                                                              #
#    02-15-2011 Dan Iredell                                             #
#########################################################################

echo "*** Started script $0"

# It is assumed that all forcing.imput files
# are already in the working directory $DATA

#DATA=`pwd`
#cd $DATA

# move original files to a temp directory
mkdir temp
for ofield in airtmp precip presur radflx  shwflx surtmp tauewd  taunwd vapmix wndspd
do
mv  forcing.${ofield}.b   temp/forcing.${ofield}.b 
mv  forcing.${ofield}.a   temp/forcing.${ofield}.a
done

# add fields using extrapolation/interpolation in ofield to cover times in ifield
# instantaneous fields
for ofield in airtmp  presur  surtmp radflx  shwflx vapmix wndspd
do 
ifield=precip
# prepare input file 
blines=`cat ./temp/forcing.${ifield}.b | wc -l`
aname=`grep span ./temp/forcing.${ifield}.b |head -1 |cut -c1-10`
num_times=`grep "${aname}" ./temp/forcing.${ifield}.b | wc -l`
ihead=`expr ${blines} \- ${num_times} `
blines=`cat ./temp/forcing.${ofield}.b | wc -l`
sname=`grep span ./temp/forcing.${ofield}.b |head -1 |cut -c1-10`
num_frames=`grep "${sname}" ./temp/forcing.${ofield}.b | wc -l`
ohead=`expr ${blines} \- ${num_frames} `

cat > timeinterp_forcing.$ofield.in <<EOF
$ifield
$ihead
$num_times
$ofield
$ohead
$num_frames
$sname
EOF

$EXECofs/hwrf_ofs_timeinterp_forcing < timeinterp_forcing.$ofield.in 

done

# averaged fields
for ofield in  precip  tauewd  taunwd 
do 
ifield=airtmp
# prepare input file 
blines=`cat ./temp/forcing.${ifield}.b | wc -l`
aname=`grep span ./temp/forcing.${ifield}.b |head -1 |cut -c1-10`
num_times=`grep "${aname}" ./temp/forcing.${ifield}.b | wc -l`
ihead=`expr ${blines} \- ${num_times} `
blines=`cat ./temp/forcing.${ofield}.b | wc -l`
sname=`grep span ./temp/forcing.${ofield}.b |head -1 |cut -c1-10`
num_frames=`grep "${sname}" ./temp/forcing.${ofield}.b | wc -l`
ohead=`expr ${blines} \- ${num_frames} `

cat > timeinterp_forcing.$ofield.in <<EOF
$ifield
$ihead
$num_times
$ofield
$ohead
$num_frames
$sname
EOF

$EXECofs/hwrf_ofs_timeinterp_forcing < timeinterp_forcing.$ofield.in

done

echo "*** Finished script $0"
